@@ -5,7 +5,7 @@ use Moose;
 use Mojo::UserAgent;
 use Data::Dumper;
 
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 
 our $AUTOLOAD;
@@ -52,12 +52,10 @@ sub _get_rere {
     my $password = $self->password;
 
     my $userpass = $username && $password ? "$username:$password\@" : '';
-    my $base_url = "http://$userpass" . join( '/', $self->url, 'redis', $method, $var );
+    my $base_url = "http://$userpass" . join( '/', $self->url, 'redis', $method, $var || "" );
 
-    if ($value) {
-        $base_url .= '/' . $value;
-        $base_url .= '/' . $extra if $extra;
-    }
+    $base_url .= '/' . $value if $value;
+    $base_url .= '/' . $extra if $extra;
 
     my $json = $self->ua->get($base_url)->res->json;
     return $json->{$method};
@@ -76,7 +74,7 @@ ReRe::Client
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 DESCRIPTION
 
